==> aws-cdk-scala-evidently_3-0.4.1-javadoc.jar: scripts/searchData.js <==
pages = [{"l":"index.html","n":"evidently","t":"evidently","d":"","k":"static"},
{"l":"io/burkard/cdk/services/evidently.html","n":"io.burkard.cdk.services.evidently","t":"package io.burkard.cdk.services.evidently","d":"io/burkard/cdk/services/evidently","k":"package"},
{"l":"io/burkard/cdk/services/evidently/CfnExperiment$.html","n":"CfnExperiment","t":"object CfnExperiment","d":"io/burkard/cdk/services/evidently/CfnExperiment$","k":"object"},
{"l":"io/burkard/cdk/services/evidently/CfnExperiment$.html","n":"apply","t":"def apply(internalResourceId: String, name: String, project: String, metricGoals: List[_], treatments: List[_], onlineAbConfig: OnlineAbConfigObjectProperty, samplingRate: Option[Number], description: Option[String], tags: Option[List[_ <: CfnTag]], randomizationSalt: Option[String])(implicit stackCtx: Stack): CfnExperiment","d":"io/burkard/cdk/services/evidently/CfnExperiment$","k":"def"},
{"l":"io/burkard/cdk/services/evidently/CfnExperimentProps$.html","n":"CfnExperimentProps","t":"object CfnExperimentProps","d":"io/burkard/cdk/services/evidently/CfnExperimentProps$","k":"object"},
{"l":"io/burkard/cdk/services/evidently/CfnExperimentProps$.html","n":"apply","t":"def apply(name: String, project: String, metricGoals: List[_], treatments: List[_], onlineAbConfig: OnlineAbConfigObjectProperty, samplingRate: Option[Number], description: Option[String], tags: Option[List[_ <: CfnTag]], randomizationSalt: Option[String]): CfnExperimentProps","d":"io/burkard/cdk/services/evidently/CfnExperimentProps$","k":"def"},
{"l":"io/burkard/cdk/services/evidently/CfnFeature$.html","n":"CfnFeature","t":"object CfnFeature","d":"io/burkard/cdk/services/evidently/CfnFeature$","k":"object"},
{"l":"io/burkard/cdk/services/evidently/CfnFeature$.html","n":"apply","t":"def apply(internalResourceId: String, name: String, project: String, variations: List[_], entityOverrides: Option[List[_]], description: Option[String], tags: Option[List[_ <: CfnTag]], defaultVariation: Option[String], evaluationStrategy: Option[String])(implicit stackCtx: Stack): CfnFeature","d":"io/burkard/cdk/services/evidently/CfnFeature$","k":"def"},
{"l":"io/burkard/cdk/services/evidently/CfnFeatureProps$.html","n":"CfnFeatureProps","t":"object CfnFeatureProps","d":"io/burkard/cdk/services/evidently/CfnFeatureProps$","k":"object"},
{"l":"io/burkard/cdk/services/evidently/CfnFeatureProps$.html","n":"apply","t":"def apply(name: String, project: String, variations: List[_], entityOverrides: Option[List[_]], description: Option[String], tags: Option[List[_ <: CfnTag]], defaultVariation: Option[String], evaluationStrategy: Option[String]): CfnFeatureProps","d":"io/burkard/cdk/services/evidently/CfnFeatureProps$","k":"def"},
{"l":"io/burkard/cdk/services/evidently/CfnLaunch$.html","n":"CfnLaunch","t":"object CfnLaunch","d":"io/burkard/cdk/services/evidently/CfnLaunch$","k":"object"},
{"l":"io/burkard/cdk/services/evidently/CfnLaunch$.html","n":"apply","t":"def apply(internalResourceId: String, name: String, project: String, groups: List[_], scheduledSplitsConfig: List[_], metricMonitors: Option[List[_]], description: Option[String], tags: Option[List[_ <: CfnTag]], randomizationSalt: Option[String])(implicit stackCtx: Stack): CfnLaunch","d":"io/burkard/cdk/services/evidently/CfnLaunch$","k":"def"},
{"l":"io/burkard/cdk/services/evidently/CfnLaunchProps$.html","n":"CfnLaunchProps","t":"object CfnLaunchProps","d":"io/burkard/cdk/services/evidently/CfnLaunchProps$","k":"object"},
{"l":"io/burkard/cdk/services/evidently/CfnLaunchProps$.html","n":"apply","t":"def apply(name: String, project: String, groups: List[_], scheduledSplitsConfig: List[_], metricMonitors: Option[List[_]], description: Option[String], tags: Option[List[_ <: CfnTag]], randomizationSalt: Option[String]): CfnLaunchProps","d":"io/burkard/cdk/services/evidently/CfnLaunchProps$","k":"def"},
{"l":"io/burkard/cdk/services/evidently/CfnProject$.html","n":"CfnProject","t":"object CfnProject","d":"io/burkard/cdk/services/evidently/CfnProject$","k":"object"},
{"l":"io/burkard/cdk/services/evidently/CfnProject$.html","n":"apply","t":"def apply(internalResourceId: String, name: String, tags: Option[List[_ <: CfnTag]], description: Option[String], dataDelivery: Option[DataDeliveryObjectProperty])(implicit stackCtx: Stack): CfnProject","d":"io/burkard/cdk/services/evidently/CfnProject$","k":"def"},
{"l":"io/burkard/cdk/services/evidently/CfnProjectProps$.html","n":"CfnProjectProps","t":"object CfnProjectProps","d":"io/burkard/cdk/services/evidently/CfnProjectProps$","k":"object"},
{"l":"io/burkard/cdk/services/evidently/CfnProjectProps$.html","n":"apply","t":"def apply(name: String, tags: Option[List[_ <: CfnTag]], description: Option[String], dataDelivery: Option[DataDeliveryObjectProperty]): CfnProjectProps","d":"io/burkard/cdk/services/evidently/CfnProjectProps$","k":"def"},
{"l":"io/burkard/cdk/services/evidently/DataDeliveryObjectProperty$.html","n":"DataDeliveryObjectProperty","t":"object DataDeliveryObjectProperty","d":"io/burkard/cdk/services/evidently/DataDeliveryObjectProperty$","k":"object"},
{"l":"io/burkard/cdk/services/evidently/DataDeliveryObjectProperty$.html","n":"apply","t":"def apply(logGroup: Option[String], s3: Option[S3DestinationProperty]): DataDeliveryObjectProperty","d":"io/burkard/cdk/services/evidently/DataDeliveryObjectProperty$","k":"def"},
{"l":"io/burkard/cdk/services/evidently/EntityOverrideProperty$.html","n":"EntityOverrideProperty","t":"object EntityOverrideProperty","d":"io/burkard/cdk/services/evidently/EntityOverrideProperty$","k":"object"},
{"l":"io/burkard/cdk/services/evidently/EntityOverrideProperty$.html","n":"apply","t":"def apply(entityId: Option[String], variation: Option[String]): EntityOverrideProperty","d":"io/burkard/cdk/services/evidently/EntityOverrideProperty$","k":"def"},
{"l":"io/burkard/cdk/services/evidently/GroupToWeightProperty$.html","n":"GroupToWeightProperty","t":"object GroupToWeightProperty","d":"io/burkard/cdk/services/evidently/GroupToWeightProperty$","k":"object"},
{"l":"io/burkard/cdk/services/evidently/GroupToWeightProperty$.html","n":"apply","t":"def apply(splitWeight: Number, groupName: String): GroupToWeightProperty","d":"io/burkard/cdk/services/evidently/GroupToWeightProperty$","k":"def"},
{"l":"io/burkard/cdk/services/evidently/LaunchGroupObjectProperty$.html","n":"LaunchGroupObjectProperty","t":"object LaunchGroupObjectProperty","d":"io/burkard/cdk/services/evidently/LaunchGroupObjectProperty$","k":"object"},
{"l":"io/burkard/cdk/services/evidently/LaunchGroupObjectProperty$.html","n":"apply","t":"def apply(feature: String, groupName: String, variation: String, description: Option[String]): LaunchGroupObjectProperty","d":"io/burkard/cdk/services/evidently/LaunchGroupObjectProperty$","k":"def"},
{"l":"io/burkard/cdk/services/evidently/MetricDefinitionObjectProperty$.html","n":"MetricDefinitionObjectProperty","t":"object MetricDefinitionObjectProperty","d":"io/burkard/cdk/services/evidently/MetricDefinitionObjectProperty$","k":"object"},
{"l":"io/burkard/cdk/services/evidently/MetricDefinitionObjectProperty$.html","n":"apply","t":"def apply(valueKey: String, entityIdKey: String, metricName: String, eventPattern: String, unitLabel: Option[String]): MetricDefinitionObjectProperty","d":"io/burkard/cdk/services/evidently/MetricDefinitionObjectProperty$","k":"def"},
{"l":"io/burkard/cdk/services/evidently/MetricGoalObjectProperty$.html","n":"MetricGoalObjectProperty","t":"object MetricGoalObjectProperty","d":"io/burkard/cdk/services/evidently/MetricGoalObjectProperty$","k":"object"},
{"l":"io/burkard/cdk/services/evidently/MetricGoalObjectProperty$.html","n":"apply","t":"def apply(valueKey: String, entityIdKey: String, metricName: String, eventPattern: String, desiredChange: String, unitLabel: Option[String]): MetricGoalObjectProperty","d":"io/burkard/cdk/services/evidently/MetricGoalObjectProperty$","k":"def"},
{"l":"io/burkard/cdk/services/evidently/OnlineAbConfigObjectProperty$.html","n":"OnlineAbConfigObjectProperty","t":"object OnlineAbConfigObjectProperty","d":"io/burkard/cdk/services/evidently/OnlineAbConfigObjectProperty$","k":"object"},
{"l":"io/burkard/cdk/services/evidently/OnlineAbConfigObjectProperty$.html","n":"apply","t":"def apply(controlTreatmentName: Option[String], treatmentWeights: Option[List[_]]): OnlineAbConfigObjectProperty","d":"io/burkard/cdk/services/evidently/OnlineAbConfigObjectProperty$","k":"def"},
{"l":"io/burkard/cdk/services/evidently/S3DestinationProperty$.html","n":"S3DestinationProperty","t":"object S3DestinationProperty","d":"io/burkard/cdk/services/evidently/S3DestinationProperty$","k":"object"},
{"l":"io/burkard/cdk/services/evidently/S3DestinationProperty$.html","n":"apply","t":"def apply(bucketName: String, prefix: Option[String]): S3DestinationProperty","d":"io/burkard/cdk/services/evidently/S3DestinationProperty$","k":"def"},
{"l":"io/burkard/cdk/services/evidently/StepConfigProperty$.html","n":"StepConfigProperty","t":"object StepConfigProperty","d":"io/burkard/cdk/services/evidently/StepConfigProperty$","k":"object"},
{"l":"io/burkard/cdk/services/evidently/StepConfigProperty$.html","n":"apply","t":"def apply(startTime: String, groupWeights: List[_]): StepConfigProperty","d":"io/burkard/cdk/services/evidently/StepConfigProperty$","k":"def"},
{"l":"io/burkard/cdk/services/evidently/TreatmentObjectProperty$.html","n":"TreatmentObjectProperty","t":"object TreatmentObjectProperty","d":"io/burkard/cdk/services/evidently/TreatmentObjectProperty$","k":"object"},
{"l":"io/burkard/cdk/services/evidently/TreatmentObjectProperty$.html","n":"apply","t":"def apply(feature: String, treatmentName: String, variation: String, description: Option[String]): TreatmentObjectProperty","d":"io/burkard/cdk/services/evidently/TreatmentObjectProperty$","k":"def"},
{"l":"io/burkard/cdk/services/evidently/TreatmentToWeightProperty$.html","n":"TreatmentToWeightProperty","t":"object TreatmentToWeightProperty","d":"io/burkard/cdk/services/evidently/TreatmentToWeightProperty$","k":"object"},
{"l":"io/burkard/cdk/services/evidently/TreatmentToWeightProperty$.html","n":"apply","t":"def apply(splitWeight: Number, treatment: String): TreatmentToWeightProperty","d":"io/burkard/cdk/services/evidently/TreatmentToWeightProperty$","k":"def"},
{"l":"io/burkard/cdk/services/evidently/VariationObjectProperty$.html","n":"VariationObjectProperty","t":"object VariationObjectProperty","d":"io/burkard/cdk/services/evidently/VariationObjectProperty$","k":"object"},
{"l":"io/burkard/cdk/services/evidently/VariationObjectProperty$.html","n":"apply","t":"def apply(doubleValue: Option[Number], variationName: Option[String], longValue: Option[Number], stringValue: Option[String], booleanValue: Option[Boolean]): VariationObjectProperty","d":"io/burkard/cdk/services/evidently/VariationObjectProperty$","k":"def"},
{"l":"docs/index.html","n":"evidently","t":"evidently","d":"","k":"static"}];

==> aws-cdk-scala-evidently_3-0.5.0-javadoc.jar: scripts/searchData.js <==
pages = [{"l":"index.html","n":"evidently","t":"evidently","d":"","k":"static"},
{"l":"io/burkard/cdk/services/evidently.html","n":"io.burkard.cdk.services.evidently","t":"package io.burkard.cdk.services.evidently","d":"io/burkard/cdk/services/evidently","k":"package"},
{"l":"io/burkard/cdk/services/evidently/CfnExperiment$.html","n":"CfnExperiment","t":"object CfnExperiment","d":"io/burkard/cdk/services/evidently/CfnExperiment$","k":"object"},
{"l":"io/burkard/cdk/services/evidently/CfnExperiment$.html","n":"apply","t":"def apply(internalResourceId: String, name: String, project: String, metricGoals: List[_], treatments: List[_], onlineAbConfig: OnlineAbConfigObjectProperty, samplingRate: Option[Number], description: Option[String], tags: Option[List[_ <: CfnTag]], randomizationSalt: Option[String])(implicit stackCtx: Stack): CfnExperiment","d":"io/burkard/cdk/services/evidently/CfnExperiment$","k":"def"},
{"l":"io/burkard/cdk/services/evidently/CfnExperimentProps$.html","n":"CfnExperimentProps","t":"object CfnExperimentProps","d":"io/burkard/cdk/services/evidently/CfnExperimentProps$","k":"object"},
{"l":"io/burkard/cdk/services/evidently/CfnExperimentProps$.html","n":"apply","t":"def apply(name: String, project: String, metricGoals: List[_], treatments: List[_], onlineAbConfig: OnlineAbConfigObjectProperty, samplingRate: Option[Number], description: Option[String], tags: Option[List[_ <: CfnTag]], randomizationSalt: Option[String]): CfnExperimentProps","d":"io/burkard/cdk/services/evidently/CfnExperimentProps$","k":"def"},
{"l":"io/burkard/cdk/services/evidently/CfnFeature$.html","n":"CfnFeature","t":"object CfnFeature","d":"io/burkard/cdk/services/evidently/CfnFeature$","k":"object"},
{"l":"io/burkard/cdk/services/evidently/CfnFeature$.html","n":"apply","t":"def apply(internalResourceId: String, name: String, project: String, variations: List[_], entityOverrides: Option[List[_]], description: Option[String], tags: Option[List[_ <: CfnTag]], defaultVariation: Option[String], evaluationStrategy: Option[String])(implicit stackCtx: Stack): CfnFeature","d":"io/burkard/cdk/services/evidently/CfnFeature$","k":"def"},
{"l":"io/burkard/cdk/services/evidently/CfnFeatureProps$.html","n":"CfnFeatureProps","t":"object CfnFeatureProps","d":"io/burkard/cdk/services/evidently/CfnFeatureProps$","k":"object"},
{"l":"io/burkard/cdk/services/evidently/CfnFeatureProps$.html","n":"apply","t":"def apply(name: String, project: String, variations: List[_], entityOverrides: Option[List[_]], description: Option[String], tags: Option[List[_ <: CfnTag]], defaultVariation: Option[String], evaluationStrategy: Option[String]): CfnFeatureProps","d":"io/burkard/cdk/services/evidently/CfnFeatureProps$","k":"def"},
{"l":"io/burkard/cdk/services/evidently/CfnLaunch$.html","n":"CfnLaunch","t":"object CfnLaunch","d":"io/burkard/cdk/services/evidently/CfnLaunch$","k":"object"},
{"l":"io/burkard/cdk/services/evidently/CfnLaunch$.html","n":"apply","t":"def apply(internalResourceId: String, name: String, project: String, groups: List[_], scheduledSplitsConfig: List[_], metricMonitors: Option[List[_]], description: Option[String], tags: Option[List[_ <: CfnTag]], randomizationSalt: Option[String])(implicit stackCtx: Stack): CfnLaunch","d":"io/burkard/cdk/services/evidently/CfnLaunch$","k":"def"},
{"l":"io/burkard/cdk/services/evidently/CfnLaunchProps$.html","n":"CfnLaunchProps","t":"object CfnLaunchProps","d":"io/burkard/cdk/services/evidently/CfnLaunchProps$","k":"object"},
{"l":"io/burkard/cdk/services/evidently/CfnLaunchProps$.html","n":"apply","t":"def apply(name: String, project: String, groups: List[_], scheduledSplitsConfig: List[_], metricMonitors: Option[List[_]], description: Option[String], tags: Option[List[_ <: CfnTag]], randomizationSalt: Option[String]): CfnLaunchProps","d":"io/burkard/cdk/services/evidently/CfnLaunchProps$","k":"def"},
{"l":"io/burkard/cdk/services/evidently/CfnProject$.html","n":"CfnProject","t":"object CfnProject","d":"io/burkard/cdk/services/evidently/CfnProject$","k":"object"},
{"l":"io/burkard/cdk/services/evidently/CfnProject$.html","n":"apply","t":"def apply(internalResourceId: String, name: String, tags: Option[List[_ <: CfnTag]], description: Option[String], dataDelivery: Option[DataDeliveryObjectProperty])(implicit stackCtx: Stack): CfnProject","d":"io/burkard/cdk/services/evidently/CfnProject$","k":"def"},
{"l":"io/burkard/cdk/services/evidently/CfnProjectProps$.html","n":"CfnProjectProps","t":"object CfnProjectProps","d":"io/burkard/cdk/services/evidently/CfnProjectProps$","k":"object"},
{"l":"io/burkard/cdk/services/evidently/CfnProjectProps$.html","n":"apply","t":"def apply(name: String, tags: Option[List[_ <: CfnTag]], description: Option[String], dataDelivery: Option[DataDeliveryObjectProperty]): CfnProjectProps","d":"io/burkard/cdk/services/evidently/CfnProjectProps$","k":"def"},
{"l":"io/burkard/cdk/services/evidently/DataDeliveryObjectProperty$.html","n":"DataDeliveryObjectProperty","t":"object DataDeliveryObjectProperty","d":"io/burkard/cdk/services/evidently/DataDeliveryObjectProperty$","k":"object"},
{"l":"io/burkard/cdk/services/evidently/DataDeliveryObjectProperty$.html","n":"apply","t":"def apply(logGroup: Option[String], s3: Option[S3DestinationProperty]): DataDeliveryObjectProperty","d":"io/burkard/cdk/services/evidently/DataDeliveryObjectProperty$","k":"def"},
{"l":"io/burkard/cdk/services/evidently/EntityOverrideProperty$.html","n":"EntityOverrideProperty","t":"object EntityOverrideProperty","d":"io/burkard/cdk/services/evidently/EntityOverrideProperty$","k":"object"},
{"l":"io/burkard/cdk/services/evidently/EntityOverrideProperty$.html","n":"apply","t":"def apply(variation: Option[String], entityId: Option[String]): EntityOverrideProperty","d":"io/burkard/cdk/services/evidently/EntityOverrideProperty$","k":"def"},
{"l":"io/burkard/cdk/services/evidently/GroupToWeightProperty$.html","n":"GroupToWeightProperty","t":"object GroupToWeightProperty","d":"io/burkard/cdk/services/evidently/GroupToWeightProperty$","k":"object"},
{"l":"io/burkard/cdk/services/evidently/GroupToWeightProperty$.html","n":"apply","t":"def apply(groupName: String, splitWeight: Number): GroupToWeightProperty","d":"io/burkard/cdk/services/evidently/GroupToWeightProperty$","k":"def"},
{"l":"io/burkard/cdk/services/evidently/LaunchGroupObjectProperty$.html","n":"LaunchGroupObjectProperty","t":"object LaunchGroupObjectProperty","d":"io/burkard/cdk/services/evidently/LaunchGroupObjectProperty$","k":"object"},
{"l":"io/burkard/cdk/services/evidently/LaunchGroupObjectProperty$.html","n":"apply","t":"def apply(feature: String, groupName: String, variation: String, description: Option[String]): LaunchGroupObjectProperty","d":"io/burkard/cdk/services/evidently/LaunchGroupObjectProperty$","k":"def"},
{"l":"io/burkard/cdk/services/evidently/MetricDefinitionObjectProperty$.html","n":"MetricDefinitionObjectProperty","t":"object MetricDefinitionObjectProperty","d":"io/burkard/cdk/services/evidently/MetricDefinitionObjectProperty$","k":"object"},
{"l":"io/burkard/cdk/services/evidently/MetricDefinitionObjectProperty$.html","n":"apply","t":"def apply(valueKey: String, entityIdKey: String, metricName: String, eventPattern: String, unitLabel: Option[String]): MetricDefinitionObjectProperty","d":"io/burkard/cdk/services/evidently/MetricDefinitionObjectProperty$","k":"def"},
{"l":"io/burkard/cdk/services/evidently/MetricGoalObjectProperty$.html","n":"MetricGoalObjectProperty","t":"object MetricGoalObjectProperty","d":"io/burkard/cdk/services/evidently/MetricGoalObjectProperty$","k":"object"},
{"l":"io/burkard/cdk/services/evidently/MetricGoalObjectProperty$.html","n":"apply","t":"def apply(valueKey: String, entityIdKey: String, metricName: String, eventPattern: String, desiredChange: String, unitLabel: Option[String]): MetricGoalObjectProperty","d":"io/burkard/cdk/services/evidently/MetricGoalObjectProperty$","k":"def"},
{"l":"io/burkard/cdk/services/evidently/OnlineAbConfigObjectProperty$.html","n":"OnlineAbConfigObjectProperty","t":"object OnlineAbConfigObjectProperty","d":"io/burkard/cdk/services/evidently/OnlineAbConfigObjectProperty$","k":"object"},
{"l":"io/burkard/cdk/services/evidently/OnlineAbConfigObjectProperty$.html","n":"apply","t":"def apply(controlTreatmentName: Option[String], treatmentWeights: Option[List[_]]): OnlineAbConfigObjectProperty","d":"io/burkard/cdk/services/evidently/OnlineAbConfigObjectProperty$","k":"def"},
{"l":"io/burkard/cdk/services/evidently/S3DestinationProperty$.html","n":"S3DestinationProperty","t":"object S3DestinationProperty","d":"io/burkard/cdk/services/evidently/S3DestinationProperty$","k":"object"},
{"l":"io/burkard/cdk/services/evidently/S3DestinationProperty$.html","n":"apply","t":"def apply(bucketName: String, prefix: Option[String]): S3DestinationProperty","d":"io/burkard/cdk/services/evidently/S3DestinationProperty$","k":"def"},
{"l":"io/burkard/cdk/services/evidently/StepConfigProperty$.html","n":"StepConfigProperty","t":"object StepConfigProperty","d":"io/burkard/cdk/services/evidently/StepConfigProperty$","k":"object"},
{"l":"io/burkard/cdk/services/evidently/StepConfigProperty$.html","n":"apply","t":"def apply(startTime: String, groupWeights: List[_]): StepConfigProperty","d":"io/burkard/cdk/services/evidently/StepConfigProperty$","k":"def"},
{"l":"io/burkard/cdk/services/evidently/TreatmentObjectProperty$.html","n":"TreatmentObjectProperty","t":"object TreatmentObjectProperty","d":"io/burkard/cdk/services/evidently/TreatmentObjectProperty$","k":"object"},
{"l":"io/burkard/cdk/services/evidently/TreatmentObjectProperty$.html","n":"apply","t":"def apply(feature: String, variation: String, treatmentName: String, description: Option[String]): TreatmentObjectProperty","d":"io/burkard/cdk/services/evidently/TreatmentObjectProperty$","k":"def"},
{"l":"io/burkard/cdk/services/evidently/TreatmentToWeightProperty$.html","n":"TreatmentToWeightProperty","t":"object TreatmentToWeightProperty","d":"io/burkard/cdk/services/evidently/TreatmentToWeightProperty$","k":"object"},
{"l":"io/burkard/cdk/services/evidently/TreatmentToWeightProperty$.html","n":"apply","t":"def apply(splitWeight: Number, treatment: String): TreatmentToWeightProperty","d":"io/burkard/cdk/services/evidently/TreatmentToWeightProperty$","k":"def"},
{"l":"io/burkard/cdk/services/evidently/VariationObjectProperty$.html","n":"VariationObjectProperty","t":"object VariationObjectProperty","d":"io/burkard/cdk/services/evidently/VariationObjectProperty$","k":"object"},
{"l":"io/burkard/cdk/services/evidently/VariationObjectProperty$.html","n":"apply","t":"def apply(doubleValue: Option[Number], variationName: Option[String], longValue: Option[Number], stringValue: Option[String], booleanValue: Option[Boolean]): VariationObjectProperty","d":"io/burkard/cdk/services/evidently/VariationObjectProperty$","k":"def"},
{"l":"docs/index.html","n":"evidently","t":"evidently","d":"","k":"static"}];
